<html>
<head>
<title>img0ch - <?cs if:Subject ?>u<?cs var:Subject ?>v<?cs /if ?>zXbhǗ</title>
<meta http-equiv="Content-Type" content="text/html; charset=Shift_JIS">
<meta http-equiv="Content-Script-Type" content="text/javascript">
<meta http-equiv="Content-Style-Type" content="text/css">
<meta name="VERSION" content="<?cs var:html_escape(VERSION) ?>">
<script src="<?cs var:html_escape(StaticURI) ?>/js/img0ch.js" charset="UTF-8"></script>
<script type="text/javascript">
//<!--
var app = Img0ch.App;
app.setBBS("<?cs var:html_escape(BBS) ?>");
app.setBBSURI("<?cs var:html_escape(BBSURI) ?>");
app.setCGIURI("<?cs var:html_escape(CGIURI) ?>");
app.setStaticURI("<?cs var:html_escape(StaticURI) ?>");
app.initForm("<?cs var:html_escape(BBS_COOKIE_PATH) ?>");
function linkAsPost(option) {
    var formElement = jQuery("#virtualThreadForm");
    formElement.append("<input type='hidden' name='option' value='" + option + "'>");
    var newFormElement = jQuery("<form>");
    newFormElement.attr({ "method": "POST", "action": formElement.attr("action") });
    newFormElement.append(jQuery( "input[@type='hidden']", formElement ));
    newFormElement.appendTo("body").get(0).submit();
    return;
}
function addInternalLinks( props, dist ) {
    var d = jQuery(dist);
    for ( var i in props ) {
        var a = jQuery("<a>").attr( "href", "#" + i );
        a.click(function(){
            /#(.+)$/.test(this.href);
            linkAsPost(RegExp.$1);
            return false
        });
        a.text(props[i]).appendTo(d);
        d.append("&nbsp;");
    }
}
function addFormLinks( props, dist ) {
    var d = jQuery(dist);
    for ( var i in props ) {
        var a = jQuery("<a>").attr( "href", "#" + i );
        a.click(function(){
            var formElement = jQuery("#virtualThreadForm");
            /#(.+)$/.test(this.href);
            formElement.append("<input type='hidden' name='mode' value='" + RegExp.$1 + "'>");
            linkAsPost();
            return false
        });
        a.text(props[i]).appendTo(d);
        d.append("&nbsp;");
    }
}
function redir(element) {
    app.redirectRenderer(element);
    return true;
}
jQuery(function(){
    var head = {
        '': "S",
        "1-": "1-",
        <?cs each:item = LinkStack ?>"<?cs var:html_escape(item.start) ?>-<?cs var:html_escape(item.end) ?>": "<?cs var:html_escape(item.start) ?>-"
<?cs /each ?>
        "l50": "ŐV50"
    };
    var foot = {
        '': "S",
        "<?cs var:html_escape(PrevStart) ?>-<?cs var:html_escape(PrevEnd) ?>": "O100",
        "<?cs var:html_escape(NextStart) ?>-<?cs var:html_escape(NextEnd) ?>": "100",
        "l50": "ŐV50"
    };
    addInternalLinks( head, "span#headInternalLinks" );
    addInternalLinks( foot, "span#footInternalLinks" );
    var page = {
        "": "\yё",
        "ngword": "NG[h",
        "setting": "Xbhݒ",
        "inherit": "ݒp"
//        "user": "[U["
    };
    addFormLinks( page, "span#headPageLinks" );
});
//-->
</script>
<style type="text/css">
<!--
.clear { clear: both; }
.image { border: none; float: left; margin-right: 4px; margin-bottom: 1px; }
/* from zeromin2.css */
.noticeFailed {
  margin: 1em 0;
  padding: 0 2.5em;
  color: #ff0000;
  background: #ffeeee;
  border: 1px solid #ff9999;
}
.noticeSuccess {
  margin: 1em 0;
  padding: 0 2.5em;
  color: #008000;
  background: #eeffee;
  border: 1px solid #99ff99;
}
-->
</style>
<?cs var:META ?>
</head>
<body bgcolor="<?cs var:html_escape(BBS_THREAD_COLOR) ?>" text="<?cs var:html_escape(BBS_TEXT_COLOR) ?>" link="<?cs var:html_escape(BBS_LINK_COLOR) ?>" alink="<?cs var:html_escape(BBS_ALINK_COLOR) ?>" vlink="<?cs var:html_escape(BBS_VLINK_COLOR) ?>">

<?cs if:Banner ?><table border="1" cellspacing="7" cellpadding="3" width="100%" bgcolor="#ccffcc" align="center"><tr><td><?cs var:Banner ?></td></tr></table><hr><?cs /if ?>

<?cs if:Validate ?>

<form id="virtualThreadForm" action="<?cs var:html_escape(CGIURI) ?>/img0ch-vta.cgi/<?cs var:html_escape(BBS) ?>/<?cs var:html_escape(KEY) ?>/" method="POST">
<a href="<?cs var:html_escape(CGIURI) ?>/img0ch-vta.cgi/<?cs var:html_escape(BBS) ?>/<?cs var:html_escape(KEY) ?>/">OIt</a>
<span id="headPageLinks"></span>
<noscript>
<select name="mode">
<option value="">Xbh\yё</option>
<option value="ngword">XbhŗLNG[h̐ݒ</option>
<option value="setting">XbhŗLȐݒ̕ύX</option>
<option value="inherit">Xbh̐ݒp</option>
<!--<option value="user">[U[̒ǉyэ폜</option>-->
</select>
</noscript>
<input type="hidden" name="bbs" value="<?cs var:html_escape(BBS) ?>">
<input type="hidden" name="key" value="<?cs var:html_escape(KEY) ?>">
<input type="hidden" name="option" value="<?cs var:html_escape(Option) ?>">
<input type="hidden" name="user" value="<?cs var:html_escape(User) ?>">
<input type="hidden" name="pass" value="<?cs var:html_escape(Pass) ?>">
<hr>
</form>

<?cs if:ModeSetting ?>

<?cs if:DoneSaveSetting ?><div class="noticeSuccess" id="notify"><p>ݒ̕ύXs܂</p></div><?cs /if ?>

<div>
<font color="<?cs var:html_escape(BBS_SUBJECT_COLOR) ?>" size="+1"> Xbh̐ݒ</font>
<ul>
<li>ݒ肳ĂȂڂSETTING.TXTɏ]Đݒ肳܂</li>
<li>lڂSETTING.TXT傫ꍇSETTING.TXT̃ftHglɍĐݒ肳܂</li>
<li>ڂ͍ő<?cs var:html_escape(SettingStringLengthMax) ?>oCg܂Őݒł܂</li>
</ul>
<form id="virtualThreadForm" action="<?cs var:html_escape(CGIURI) ?>/img0ch-vta.cgi/<?cs var:html_escape(BBS) ?>/<?cs var:html_escape(KEY) ?>/" method="POST">
<label>s̍ő啶</label><br>
<input type="text" name="BBS_COLUMN_NUMBER" value="<?cs var:html_escape(BBS_COLUMN_NUMBER) ?>"><br>
<label>Xbh̍őe</label><br>
<input type="text" name="BBS_DATMAX" value="<?cs var:html_escape(BBS_DATMAX) ?>"><br>
<label>{̍ős</label><br>
<input type="text" name="BBS_LINE_NUMBER" value="<?cs var:html_escape(BBS_LINE_NUMBER) ?>"><br>
<label>[̍ő啶(oCgP)</label><br>
<input type="text" name="BBS_MAIL_COUNT" value="<?cs var:html_escape(BBS_MAIL_COUNT) ?>"><br>
<label>{̍ő啶(oCgP)</label><br>
<input type="text" name="BBS_MESSAGE_COUNT" value="<?cs var:html_escape(BBS_MESSAGE_COUNT) ?>"><br>
<label>O̍ő啶(oCgP)</label><br>
<input type="text" name="BBS_NAME_COUNT" value="<?cs var:html_escape(BBS_NAME_COUNT) ?>"><br>
<label>ő僌X</label><br>
<input type="text" name="BBS_RES_MAX" value="<?cs var:html_escape(BBS_RES_MAX) ?>"><br>
<label>̃ftHg</label><br>
<input type="text" name="BBS_NONAME_NAME" value="<?cs var:html_escape(BBS_NONAME_NAME) ?>"><br>
<label>폜̕(zXbhǗł̍폜̂ݗL)</label><br>
<input type="text" name="BBS_DELETE_NAME" value="<?cs var:html_escape(BBS_DELETE_NAME) ?>"><br><br>
<input type="submit" name="submit" value="ݒXV">
<input type="hidden" name="mode" value="setting">
<input type="hidden" name="bbs" value="<?cs var:html_escape(BBS) ?>">
<input type="hidden" name="key" value="<?cs var:html_escape(KEY) ?>">
<input type="hidden" name="option" value="<?cs var:html_escape(Option) ?>">
<input type="hidden" name="user" value="<?cs var:html_escape(User) ?>">
<input type="hidden" name="pass" value="<?cs var:html_escape(Pass) ?>">
</form>
<hr>
</div>

<?cs elif:ModeNGword ?>

<?cs if:DoneSaveNGWord ?><div class="noticeSuccess" id="notify"><p>NG[hXg̍XVs܂</p></div><?cs /if ?>
<?cs if:TooManyNGWordError ?><div class="noticeFailed" id="notify"><p>NG[h̐ݒ𒴂Ă܂</p></div><?cs /if ?>

<div>
<font color="<?cs var:html_escape(BBS_SUBJECT_COLOR) ?>" size="+1"> XbhNG[h</font>
<ul>
<li>PЂƂɂ<?cs var:html_escape(NGWordLengthLimit) ?>oCg܂Őݒ\ł</li>
<li>ő<?cs var:html_escape(NGWordCountLimit) ?>P܂Őݒ\ł</li>
</ul>
<form id="virtualThreadForm" action="<?cs var:html_escape(CGIURI) ?>/img0ch-vta.cgi/<?cs var:html_escape(BBS) ?>/<?cs var:html_escape(KEY) ?>/" method="POST">
<textarea name="ngword" cols="60" rows="10"><?cs var:html_escape(NGWords) ?></textarea><br><br>
<input type="submit" name="submit" value="ݒXV">
<input type="hidden" name="mode" value="ngword">
<input type="hidden" name="bbs" value="<?cs var:html_escape(BBS) ?>">
<input type="hidden" name="key" value="<?cs var:html_escape(KEY) ?>">
<input type="hidden" name="option" value="<?cs var:html_escape(Option) ?>">
<input type="hidden" name="user" value="<?cs var:html_escape(User) ?>">
<input type="hidden" name="pass" value="<?cs var:html_escape(Pass) ?>">
</form>
<hr>
</div>

<?cs elif:ModeInherit ?>

<?cs if:InheritedOK ?><div class="noticeSuccess" id="notify"><p>zXbȟpɐ܂</p></div><?cs /if ?>
<?cs if:InheritedNG ?><div class="noticeFailed" id="notify"><p>zXbȟpɎs܂</p></div><?cs /if ?>

<div>
<font color="<?cs var:html_escape(BBS_SUBJECT_COLOR) ?>" size="+1"> zXbh̐ݒp</font>
<p>
p̃XbhɃ[UƃpX[h݂A<br>
ꂼꓯ̂̂łΉzXbh̐ݒp܂B
</p>
<form id="virtualThreadForm" action="<?cs var:html_escape(CGIURI) ?>/img0ch-vta.cgi/<?cs var:html_escape(BBS) ?>/<?cs var:html_escape(KEY) ?>/" method="POST">
<select name="inherit_from">
<?cs each:item = Threads ?><option value="<?cs var:html_escape(item.key) ?>"><?cs var:html_escape(item.subject) ?> (<?cs var:html_escape(item.res) ?>)</option>
<?cs /each ?></select>
<input type="submit" name="submit" value="ݒ̌p">
<input type="hidden" name="mode" value="inherit">
<input type="hidden" name="bbs" value="<?cs var:html_escape(BBS) ?>">
<input type="hidden" name="key" value="<?cs var:html_escape(KEY) ?>">
<input type="hidden" name="option" value="<?cs var:html_escape(Option) ?>">
<input type="hidden" name="user" value="<?cs var:html_escape(User) ?>">
<input type="hidden" name="pass" value="<?cs var:html_escape(Pass) ?>">
</form>
<hr>
</div>

<?cs elif:View ?>

<form id="virtualThreadForm" action="<?cs var:html_escape(CGIURI) ?>/img0ch-vta.cgi/<?cs var:html_escape(BBS) ?>/<?cs var:html_escape(KEY) ?>/" method="POST">
<?cs if:DoneRemoveRes ?><div class="noticeSuccess" id="notify"><p>IꂽX폜܂</p></div><?cs /if ?>
<?cs if:DoneRemoveFile ?><div class="noticeSuccess" id="notify"><p>IꂽX̓Ytt@C폜܂</p></div><?cs /if ?>
<?cs if:DoneStopThread ?><div class="noticeSuccess" id="notify"><p>Xbh~܂</p></div><?cs /if ?>
<?cs if:DoneRestartThread ?><div class="noticeSuccess" id="notify"><p>XbhĊJ܂</p></div><?cs /if ?>
<?cs if:DoneDenyRemoteHost ?><div class="noticeSuccess" id="notify"><p>IꂽX̃zXg̓eۂ܂</p></div><?cs /if ?>
<?cs if:DoneAllowRemoteHost ?><div class="noticeSuccess" id="notify"><p>IꂽX̃zXg̓e܂</p></div><?cs /if
?>

<a href="<?cs var:html_escape(BBSURI) ?>/">fɖ߂遡</a>
<?cs if:Uploadable ?><a href="<?cs var:html_escape(CGIURI) ?>/img0ch-ufm.cgi/<?cs var:html_escape(BBS) ?>/<?cs var:html_escape(KEY) ?>/">t@CǗ</a><?cs /if ?>
<span id="headInternalLinks"></span>
<noscript>
<select name="option">
<option value="">SẴX</option>
<?cs each:item = LinkStack ?><option value="<?cs var:html_escape(item.start) ?>-<?cs var:html_escape(item.end) ?>"><?cs var:html_escape(item.start) ?>-</option>
<?cs /each ?>
<option value="l50">ŐV50</option>
</select>
<input type="submit" value="ǂݍ">
</noscript>
<br>
<select name="method">
<option value="">[ȉIĂ]</option>
<option value="remove_res">IꂽXʏ폜</option>
<!--<option value="edit_res">IꂽXҏW</option>-->
<option value="remove_file">IꂽX̓Ytt@Ĉݍ폜</option>
<option value="stop">Xbh̒~</option>
<option value="restart">Xbh̍ĊJ</option>
<option value="deny">IꂽX̏݌ۂ</option>
<option value="allow">IꂽX̏݌</option>
</select>
<input type="submit" name="submit" value="s" />
<ul>
<li>̃v_Ej[ŕ@IAusvNbN</li>
<li>XԍNbN邱Ƃɂ背XҏWʂɈڍs</li>
<li>uvNbN邱Ƃɂ肱Ƀy[Wړ܂</li>
</ul>
<hr>

<dl>
<font color="<?cs var:html_escape(BBS_SUBJECT_COLOR) ?>" size="+1"> <?cs var:Subject ?></font><br><br>

<?cs each:item = Thread ?><dt><input type="checkbox" name="resno" value="<?cs var:html_escape(item.resno) ?>"> <?cs var:html_escape(item.resno) ?> OF<b><?cs if:item.mail ?><a href="mailto:<?cs var:html_escape(item.mail) ?>"><?cs var:item.name ?></a><?cs else ?><font color="<?cs var:html_escape(BBS_NAME_COLOR) ?>"><?cs var:item.name ?></font><?cs /if ?></b>F<?cs var:item.date ?> <a href="#virtualThreadForm"></a></dt><dd><?cs var:item.text ?><br><br></dd>
<?cs /each ?>
</dl>

<font color=red face="Arial"><b><?cs var:html_escape(DatKByteSize) ?>KB</b></font>
<hr><center><a href="<?cs var:html_escape(ReadCGIURI) ?>/<?cs var:html_escape(ResCount) ?>-n">VX̕\</a></center><hr>
<a href="<?cs var:html_escape(BBSURI) ?>/">fɖ߂</a>
<?cs if:Uploadable ?><a href="<?cs var:html_escape(CGIURI) ?>/img0ch-ufm.cgi/<?cs var:html_escape(BBS) ?>/<?cs var:html_escape(KEY) ?>/">t@CǗ</a><?cs /if ?>
<span id="footInternalLinks"></span>
<noscript>
<select name="option">
<option value="">SẴX</option>
<option value="<?cs var:html_escape(PrevStart) ?>-<?cs var:html_escape(PrevEnd) ?>">O100X</option>
<option value="<?cs var:html_escape(NextStart) ?>-<?cs var:html_escape(NextEnd) ?>">100X</option>
<option value="l50">ŐV50</option>
</select>
<input type="submit" value="ǂݍ">
</noscript>
<input type="hidden" name="bbs" value="<?cs var:html_escape(BBS) ?>">
<input type="hidden" name="key" value="<?cs var:html_escape(KEY) ?>">
<input type="hidden" name="option" value="<?cs var:html_escape(Option) ?>">
<input type="hidden" name="user" value="<?cs var:html_escape(User) ?>">
<input type="hidden" name="pass" value="<?cs var:html_escape(Pass) ?>">
</form>

<?cs if:!R100 ?>
<form class="comment" method="POST" action="<?cs var:html_escape(CGIURI) ?>/bbs.cgi" enctype="multipart/form-data">
<input type="hidden" name="bbs" value="<?cs var:html_escape(BBS) ?>">
<input type="hidden" name="key" value="<?cs var:html_escape(KEY) ?>">
<input type="hidden" name="time" value="<?cs var:html_escape(TimeStamp) ?>">
<input type="submit" value="">
OF<input type=text id="FROM" name="FROM" value="" size="19">
E-mail<font size=1>iȗj</font>F<input type=text id="mail" name="mail" value="" size="19"><br>
<?cs if:UploadableFromRes ?>摜F<input type="file" name="file" size="82"><br><?cs /if ?>
<?cs if:Icon ?>ACRF<select name="icon"><option value="" selected>Ȃ</option>
<?cs each:item = Icons ?><option value="<?cs var:item.id ?>"><?cs var:item.name ?></option>
<?cs /each ?></select><br><?cs /if ?>
<textarea rows="5" cols="70" wrap="off" id="MESSAGE" name="MESSAGE"></textarea><br>
<?cs if:UploadableFromRes ?>폜pXF<input type="password" name="pass"><br><?cs /if ?>
</form>
<?cs /if ?>

<?cs /if ?>

<small><a href="http://img0ch.sourceforge.jp">img0ch-vta.cgi - img0ch BBS</a></small>

<?cs else ?>

<?cs if:AuthFailed ?><div class="noticeFailed" id="notify"><p>[U[܂̓pX[hႢ܂</p></div><?cs /if ?>
<form action="<?cs var:html_escape(CGIURI) ?>/img0ch-vta.cgi/<?cs var:html_escape(BBS) ?>/<?cs var:html_escape(KEY) ?>/" method="POST">
<table border="1" cellspacing="7" cellpadding="3" width="100%" bgcolor="<?cs var:html_escape(BBS_MENU_COLOR) ?>">
<tr><td>
<p>
<a href="<?cs var:html_escape(BBSURI) ?>/">fɖ߂</a>
<a href="<?cs var:html_escape(CGIURI) ?>/read.cgi/<?cs var:html_escape(BBS) ?>/<?cs var:html_escape(KEY) ?>/l50" onclick="redir(this)">Xbhɖ߂</a>
<?cs if:Uploadable ?><a href="<?cs var:html_escape(CGIURI) ?>/img0ch-ufm.cgi/<?cs var:html_escape(BBS) ?>/<?cs var:html_escape(KEY) ?>/">t@CǗ</a><?cs /if ?>
</p>
<table>
<tr><td>[U[</td><td><input type="text" name="user"></td></tr>
<tr><td>pX[h</td><td><input type="password" name="pass"></td></tr>
<tr><td colspan="2"><input type="submit" value="F"></td></tr>
</table>
</td></tr>
</table>
</form>

<div id="VERSION"><small><a href="http://img0ch.sourceforge.jp">img0ch-vta.cgi - img0ch BBS</a></small></div>

<?cs /if ?>

</body>
</html>
